# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`python`](#python): Installs and manages python, python-dev and gunicorn.
* [`python::pip::bootstrap`](#python--pip--bootstrap): allow to bootstrap pip when python is managed from other module

#### Private Classes

* `python::config`: Optionally installs the gunicorn service
* `python::install`: Installs core python packages
* `python::params`: The python Module default configuration settings.

### Defined types

* [`python::dotfile`](#python--dotfile): Manages any python dotfiles with a simple config hash.
* [`python::gunicorn`](#python--gunicorn): Manages Gunicorn virtual hosts.
* [`python::pip`](#python--pip): Installs and manages packages from pip.
* [`python::pyvenv`](#python--pyvenv): Create a Python3 virtualenv using pyvenv.
* [`python::requirements`](#python--requirements): Installs and manages Python packages from requirements file.

### Data types

* [`Python::Loglevel`](#Python--Loglevel): Match all valid loglevels for python
* [`Python::Package::Ensure`](#Python--Package--Ensure): Match all valid package ensures for python
* [`Python::Provider`](#Python--Provider): Match all valid provider for python
* [`Python::Umask`](#Python--Umask): Match valid umask for python
* [`Python::Venv::PipVersion`](#Python--Venv--PipVersion): A version type to ensure a specific Pip version in a virtual env.
* [`Python::Version`](#Python--Version): Match all valid versions for python

## Classes

### <a name="python"></a>`python`

Installs and manages python, python-dev and gunicorn.

#### Examples

##### install python from system python

```puppet
class { 'python':
  version    => 'system',
  pip        => 'present',
  dev        => 'present',
  gunicorn   => 'present',
}
```

##### install python3 from scl repo

```puppet
class { 'python' :
  ensure      => 'present',
  version     => 'rh-python36-python',
  dev         => 'present',
}
```

#### Parameters

The following parameters are available in the `python` class:

* [`ensure`](#-python--ensure)
* [`version`](#-python--version)
* [`pip`](#-python--pip)
* [`dev`](#-python--dev)
* [`gunicorn`](#-python--gunicorn)
* [`manage_gunicorn`](#-python--manage_gunicorn)
* [`provider`](#-python--provider)
* [`use_epel`](#-python--use_epel)
* [`manage_scl`](#-python--manage_scl)
* [`umask`](#-python--umask)
* [`manage_gunicorn`](#-python--manage_gunicorn)
* [`manage_python_package`](#-python--manage_python_package)
* [`manage_venv_package`](#-python--manage_venv_package)
* [`manage_pip_package`](#-python--manage_pip_package)
* [`venv`](#-python--venv)
* [`gunicorn_package_name`](#-python--gunicorn_package_name)
* [`python_pips`](#-python--python_pips)
* [`python_pyvenvs`](#-python--python_pyvenvs)
* [`python_requirements`](#-python--python_requirements)
* [`python_dotfiles`](#-python--python_dotfiles)
* [`rhscl_use_public_repository`](#-python--rhscl_use_public_repository)
* [`anaconda_installer_url`](#-python--anaconda_installer_url)
* [`anaconda_install_path`](#-python--anaconda_install_path)

##### <a name="-python--ensure"></a>`ensure`

Data type: `Python::Package::Ensure`

Desired installation state for the Python package.

Default value: `'present'`

##### <a name="-python--version"></a>`version`

Data type: `Python::Version`

Python version to install. Beware that valid values for this differ a) by the provider you choose and b) by the osfamily/operatingsystem you are using.
Allowed values:
 - provider == pip: everything pip allows as a version after the 'python=='
 - else: 'system', 'pypy', 3/3.3/...
    - Be aware that 'system' usually means python 2.X.
    - 'pypy' actually lets us use pypy as python.
    - 3/3.3/... means you are going to install the python3/python3.3/...
      package, if available on your osfamily.

Default value: `$facts['os']['family'] ? { 'Archlinux' => 'system', default => '3'`

##### <a name="-python--pip"></a>`pip`

Data type: `Python::Package::Ensure`

Desired installation state for the python-pip package.

Default value: `'present'`

##### <a name="-python--dev"></a>`dev`

Data type: `Python::Package::Ensure`

Desired installation state for the python-dev package.

Default value: `'absent'`

##### <a name="-python--gunicorn"></a>`gunicorn`

Data type: `Python::Package::Ensure`

Desired installation state for Gunicorn.

Default value: `'absent'`

##### <a name="-python--manage_gunicorn"></a>`manage_gunicorn`

Data type: `Boolean`

Allow Installation / Removal of Gunicorn.

Default value: `true`

##### <a name="-python--provider"></a>`provider`

Data type: `Optional[Python::Provider]`

What provider to use for installation of the packages, except gunicorn and Python itself.

Default value: `undef`

##### <a name="-python--use_epel"></a>`use_epel`

Data type: `Boolean`

to determine if the epel class is used.

Default value: `$python::params::use_epel`

##### <a name="-python--manage_scl"></a>`manage_scl`

Data type: `Boolean`

Whether to manage core SCL packages or not.

Default value: `true`

##### <a name="-python--umask"></a>`umask`

Data type: `Optional[Python::Umask]`

The default umask for invoked exec calls.

Default value: `undef`

##### <a name="-python--manage_gunicorn"></a>`manage_gunicorn`

manage the state for package gunicorn

Default value: `true`

##### <a name="-python--manage_python_package"></a>`manage_python_package`

Data type: `Boolean`

manage the state for package python

Default value: `true`

##### <a name="-python--manage_venv_package"></a>`manage_venv_package`

Data type: `Boolean`

manage the state for package venv

Default value: `$python::params::manage_venv_package`

##### <a name="-python--manage_pip_package"></a>`manage_pip_package`

Data type: `Boolean`

manage the state for package pip

Default value: `$python::params::manage_pip_package`

##### <a name="-python--venv"></a>`venv`

Data type: `Python::Package::Ensure`



Default value: `'absent'`

##### <a name="-python--gunicorn_package_name"></a>`gunicorn_package_name`

Data type: `String[1]`



Default value: `$python::params::gunicorn_package_name`

##### <a name="-python--python_pips"></a>`python_pips`

Data type: `Hash`



Default value: `{}`

##### <a name="-python--python_pyvenvs"></a>`python_pyvenvs`

Data type: `Hash`



Default value: `{}`

##### <a name="-python--python_requirements"></a>`python_requirements`

Data type: `Hash`



Default value: `{}`

##### <a name="-python--python_dotfiles"></a>`python_dotfiles`

Data type: `Hash`



Default value: `{}`

##### <a name="-python--rhscl_use_public_repository"></a>`rhscl_use_public_repository`

Data type: `Boolean`



Default value: `true`

##### <a name="-python--anaconda_installer_url"></a>`anaconda_installer_url`

Data type: `Stdlib::Httpurl`



Default value: `'https://repo.anaconda.com/archive/Anaconda3-5.2.0-Linux-x86_64.sh'`

##### <a name="-python--anaconda_install_path"></a>`anaconda_install_path`

Data type: `Stdlib::Absolutepath`



Default value: `'/opt/python'`

### <a name="python--pip--bootstrap"></a>`python::pip::bootstrap`

allow to bootstrap pip when python is managed from other module

#### Examples

##### 

```puppet
class { 'python::pip::bootstrap':
  version => 'pip',
}
```

#### Parameters

The following parameters are available in the `python::pip::bootstrap` class:

* [`version`](#-python--pip--bootstrap--version)
* [`manage_python`](#-python--pip--bootstrap--manage_python)
* [`http_proxy`](#-python--pip--bootstrap--http_proxy)
* [`exec_provider`](#-python--pip--bootstrap--exec_provider)

##### <a name="-python--pip--bootstrap--version"></a>`version`

Data type: `Enum['pip', 'pip3']`

should be pip or pip3

Default value: `'pip'`

##### <a name="-python--pip--bootstrap--manage_python"></a>`manage_python`

Data type: `Variant[Boolean, String]`

if python module will manage deps

Default value: `false`

##### <a name="-python--pip--bootstrap--http_proxy"></a>`http_proxy`

Data type: `Optional[Stdlib::HTTPUrl]`

Proxy server to use for outbound connections.

Default value: `undef`

##### <a name="-python--pip--bootstrap--exec_provider"></a>`exec_provider`

Data type: `String[1]`



Default value: `'shell'`

## Defined types

### <a name="python--dotfile"></a>`python::dotfile`

Manages any python dotfiles with a simple config hash.

#### Examples

##### Create a pip config in /var/lib/jenkins/.pip/

```puppet
python::dotfile { '/var/lib/jenkins/.pip/pip.conf':
  ensure => present,
  owner  => 'jenkins',
  group  => 'jenkins',
  config => {
    'global' => {
      'index-url'       => 'https://mypypi.acme.com/simple/'
      'extra-index-url' => 'https://pypi.risedev.at/simple/'
    }
  }
}
```

#### Parameters

The following parameters are available in the `python::dotfile` defined type:

* [`ensure`](#-python--dotfile--ensure)
* [`filename`](#-python--dotfile--filename)
* [`mode`](#-python--dotfile--mode)
* [`owner`](#-python--dotfile--owner)
* [`group`](#-python--dotfile--group)
* [`config`](#-python--dotfile--config)

##### <a name="-python--dotfile--ensure"></a>`ensure`

Data type: `Enum['absent', 'present']`



Default value: `'present'`

##### <a name="-python--dotfile--filename"></a>`filename`

Data type: `Stdlib::Absolutepath`

Filename.

Default value: `$title`

##### <a name="-python--dotfile--mode"></a>`mode`

Data type: `Stdlib::Filemode`

File mode.

Default value: `'0644'`

##### <a name="-python--dotfile--owner"></a>`owner`

Data type: `String[1]`

user owner of dotfile

Default value: `'root'`

##### <a name="-python--dotfile--group"></a>`group`

Data type: `String[1]`

group owner of dotfile

Default value: `'root'`

##### <a name="-python--dotfile--config"></a>`config`

Data type: `Hash`

Config hash. This will be expanded to an ini-file.

Default value: `{}`

### <a name="python--gunicorn"></a>`python::gunicorn`

Manages Gunicorn virtual hosts.

#### Examples

##### run gunicorn on vhost in virtualenv /var/www/project1

```puppet
python::gunicorn { 'vhost':
  ensure      => present,
  virtualenv  => '/var/www/project1',
  mode        => 'wsgi',
  dir         => '/var/www/project1/current',
  bind        => 'unix:/tmp/gunicorn.socket',
  environment => 'prod',
  owner       => 'www-data',
  group       => 'www-data',
  appmodule   => 'app:app',
  osenv       => { 'DBHOST' => 'dbserver.example.com' },
  timeout     => 30,
  template    => 'python/gunicorn.erb',
}
```

#### Parameters

The following parameters are available in the `python::gunicorn` defined type:

* [`ensure`](#-python--gunicorn--ensure)
* [`config_dir`](#-python--gunicorn--config_dir)
* [`manage_config_dir`](#-python--gunicorn--manage_config_dir)
* [`virtualenv`](#-python--gunicorn--virtualenv)
* [`mode`](#-python--gunicorn--mode)
* [`dir`](#-python--gunicorn--dir)
* [`bind`](#-python--gunicorn--bind)
* [`environment`](#-python--gunicorn--environment)
* [`appmodule`](#-python--gunicorn--appmodule)
* [`osenv`](#-python--gunicorn--osenv)
* [`timeout`](#-python--gunicorn--timeout)
* [`template`](#-python--gunicorn--template)
* [`args`](#-python--gunicorn--args)
* [`owner`](#-python--gunicorn--owner)
* [`group`](#-python--gunicorn--group)
* [`workers`](#-python--gunicorn--workers)
* [`access_log_format`](#-python--gunicorn--access_log_format)
* [`accesslog`](#-python--gunicorn--accesslog)
* [`errorlog`](#-python--gunicorn--errorlog)
* [`log_level`](#-python--gunicorn--log_level)

##### <a name="-python--gunicorn--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `present`

##### <a name="-python--gunicorn--config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

Configure the gunicorn config directory path.

Default value: `'/etc/gunicorn.d'`

##### <a name="-python--gunicorn--manage_config_dir"></a>`manage_config_dir`

Data type: `Boolean`

Set if the gunicorn config directory should be created.

Default value: `false`

##### <a name="-python--gunicorn--virtualenv"></a>`virtualenv`

Data type: `Variant[Boolean,Stdlib::Absolutepath]`

Run in virtualenv, specify directory.

Default value: `false`

##### <a name="-python--gunicorn--mode"></a>`mode`

Data type: `Enum['wsgi', 'django']`

Gunicorn mode.

Default value: `'wsgi'`

##### <a name="-python--gunicorn--dir"></a>`dir`

Data type: `Stdlib::Absolutepath`

Application directory.

##### <a name="-python--gunicorn--bind"></a>`bind`

Data type: `Variant[String[1],Boolean]`

Bind on: 'HOST', 'HOST:PORT', 'unix:PATH'.
Default: system-wide: unix:/tmp/gunicorn-$name.socket
         virtualenv:  unix:${virtualenv}/${name}.socket

Default value: `false`

##### <a name="-python--gunicorn--environment"></a>`environment`

Data type: `Variant[String[1],Boolean]`

Set ENVIRONMENT variable.

Default value: `false`

##### <a name="-python--gunicorn--appmodule"></a>`appmodule`

Data type: `String[1]`

Set the application module name for gunicorn to load when not using Django.

Default value: `'app:app'`

##### <a name="-python--gunicorn--osenv"></a>`osenv`

Data type: `Variant[Boolean,Hash]`

Allows setting environment variables for the gunicorn service. Accepts a hash of 'key': 'value' pairs.

Default value: `false`

##### <a name="-python--gunicorn--timeout"></a>`timeout`

Data type: `Integer`

Allows setting the gunicorn idle worker process time before being killed. The unit of time is seconds.

Default value: `30`

##### <a name="-python--gunicorn--template"></a>`template`

Data type: `String[1]`

Which ERB template to use.

Default value: `'python/gunicorn.erb'`

##### <a name="-python--gunicorn--args"></a>`args`

Data type: `Array`

Custom arguments to add in gunicorn config file.

Default value: `[]`

##### <a name="-python--gunicorn--owner"></a>`owner`

Data type: `String[1]`



Default value: `'www-data'`

##### <a name="-python--gunicorn--group"></a>`group`

Data type: `String[1]`



Default value: `'www-data'`

##### <a name="-python--gunicorn--workers"></a>`workers`

Data type: `Variant[Boolean,Integer]`



Default value: `false`

##### <a name="-python--gunicorn--access_log_format"></a>`access_log_format`

Data type: `Variant[Boolean,String[1]]`



Default value: `false`

##### <a name="-python--gunicorn--accesslog"></a>`accesslog`

Data type: `Variant[Boolean,Stdlib::Absolutepath]`



Default value: `false`

##### <a name="-python--gunicorn--errorlog"></a>`errorlog`

Data type: `Variant[Boolean,Stdlib::Absolutepath]`



Default value: `false`

##### <a name="-python--gunicorn--log_level"></a>`log_level`

Data type: `Python::Loglevel`



Default value: `'error'`

### <a name="python--pip"></a>`python::pip`

Installs and manages packages from pip.

#### Examples

##### Install Flask to /var/www/project1 using a proxy

```puppet
python::pip { 'flask':
  virtualenv => '/var/www/project1',
  proxy      => 'http://proxy.domain.com:3128',
  index      => 'http://www.example.com/simple/',
}
```

##### Install cx_Oracle with pip

```puppet
python::pip { 'cx_Oracle' :
  pkgname       => 'cx_Oracle',
  ensure        => '5.1.2',
  virtualenv    => '/var/www/project1',
  owner         => 'appuser',
  proxy         => 'http://proxy.domain.com:3128',
  environment   => ['ORACLE_HOME=/usr/lib/oracle/11.2/client64'],
  install_args  => '-e',
  timeout       => 1800,
}
```

##### Install Requests with pip3

```puppet
python::pip { 'requests' :
  ensure        => 'present',
  pkgname       => 'requests',
  pip_provider  => 'pip3',
  virtualenv    => '/var/www/project1',
  owner         => 'root',
  timeout       => 1800
}
```

#### Parameters

The following parameters are available in the `python::pip` defined type:

* [`name`](#-python--pip--name)
* [`pkgname`](#-python--pip--pkgname)
* [`ensure`](#-python--pip--ensure)
* [`virtualenv`](#-python--pip--virtualenv)
* [`pip_provider`](#-python--pip--pip_provider)
* [`url`](#-python--pip--url)
* [`owner`](#-python--pip--owner)
* [`group`](#-python--pip--group)
* [`index`](#-python--pip--index)
* [`extra_index`](#-python--pip--extra_index)
* [`proxy`](#-python--pip--proxy)
* [`editable`](#-python--pip--editable)
* [`environment`](#-python--pip--environment)
* [`extras`](#-python--pip--extras)
* [`timeout`](#-python--pip--timeout)
* [`install_args`](#-python--pip--install_args)
* [`uninstall_args`](#-python--pip--uninstall_args)
* [`log_dir`](#-python--pip--log_dir)
* [`egg`](#-python--pip--egg)
* [`umask`](#-python--pip--umask)
* [`path`](#-python--pip--path)
* [`exec_provider`](#-python--pip--exec_provider)

##### <a name="-python--pip--name"></a>`name`

must be unique

##### <a name="-python--pip--pkgname"></a>`pkgname`

Data type: `String[1]`

the name of the package.

Default value: `$name`

##### <a name="-python--pip--ensure"></a>`ensure`

Data type: `Variant[Enum[present, absent, latest], String[1]]`

Require pip to be available.

Default value: `present`

##### <a name="-python--pip--virtualenv"></a>`virtualenv`

Data type: `Variant[Enum['system'], Stdlib::Absolutepath]`

virtualenv to run pip in.

Default value: `'system'`

##### <a name="-python--pip--pip_provider"></a>`pip_provider`

Data type: `String[1]`

version of pip you wish to use.

Default value: `'pip'`

##### <a name="-python--pip--url"></a>`url`

Data type: `Variant[Boolean, String]`

URL to install from.

Default value: `false`

##### <a name="-python--pip--owner"></a>`owner`

Data type: `String[1]`

The owner of the virtualenv being manipulated.

Default value: `'root'`

##### <a name="-python--pip--group"></a>`group`

Data type: `Optional[String[1]]`

The group of the virtualenv being manipulated.

Default value: `getvar('python::params::group')`

##### <a name="-python--pip--index"></a>`index`

Data type: `Variant[Boolean,String[1]]`

Base URL of Python package index.

Default value: `false`

##### <a name="-python--pip--extra_index"></a>`extra_index`

Data type: `Variant[Boolean,String[1]]`

Base URL of extra Python package index.

Default value: `false`

##### <a name="-python--pip--proxy"></a>`proxy`

Data type: `Optional[Stdlib::HTTPUrl]`

Proxy server to use for outbound connections.

Default value: `undef`

##### <a name="-python--pip--editable"></a>`editable`

Data type: `Boolean`

If true the package is installed as an editable resource.

Default value: `false`

##### <a name="-python--pip--environment"></a>`environment`

Data type: `Array`

Additional environment variables required to install the packages.

Default value: `[]`

##### <a name="-python--pip--extras"></a>`extras`

Data type: `Array`

Extra features provided by the package which should be installed.

Default value: `[]`

##### <a name="-python--pip--timeout"></a>`timeout`

Data type: `Numeric`

The maximum time in seconds the "pip install" command should take.

Default value: `1800`

##### <a name="-python--pip--install_args"></a>`install_args`

Data type: `Optional[String[1]]`

Any additional installation arguments that will be supplied when running pip install.

Default value: `undef`

##### <a name="-python--pip--uninstall_args"></a>`uninstall_args`

Data type: `Optional[String[1]]`

Any additional arguments that will be supplied when running pip uninstall.

Default value: `undef`

##### <a name="-python--pip--log_dir"></a>`log_dir`

Data type: `String[1]`

Log directory

Default value: `'/tmp'`

##### <a name="-python--pip--egg"></a>`egg`

Data type: `Any`

The egg name to use

Default value: `false`

##### <a name="-python--pip--umask"></a>`umask`

Data type: `Optional[Python::Umask]`



Default value: `undef`

##### <a name="-python--pip--path"></a>`path`

Data type: `Array[String]`



Default value: `['/usr/local/bin','/usr/bin','/bin', '/usr/sbin']`

##### <a name="-python--pip--exec_provider"></a>`exec_provider`

Data type: `String[1]`



Default value: `'shell'`

### <a name="python--pyvenv"></a>`python::pyvenv`

Create a Python3 virtualenv using pyvenv.

#### Examples

##### 

```puppet
python::pyvenv { '/var/www/project1' :
  ensure       => present,
  version      => 'system',
  systempkgs   => true,
  venv_dir     => '/home/appuser/virtualenvs',
  owner        => 'appuser',
  group        => 'apps',
}
```

#### Parameters

The following parameters are available in the `python::pyvenv` defined type:

* [`ensure`](#-python--pyvenv--ensure)
* [`version`](#-python--pyvenv--version)
* [`systempkgs`](#-python--pyvenv--systempkgs)
* [`venv_dir`](#-python--pyvenv--venv_dir)
* [`owner`](#-python--pyvenv--owner)
* [`group`](#-python--pyvenv--group)
* [`mode`](#-python--pyvenv--mode)
* [`path`](#-python--pyvenv--path)
* [`environment`](#-python--pyvenv--environment)
* [`prompt`](#-python--pyvenv--prompt)
* [`pip_version`](#-python--pyvenv--pip_version)

##### <a name="-python--pyvenv--ensure"></a>`ensure`

Data type: `Python::Package::Ensure`



Default value: `present`

##### <a name="-python--pyvenv--version"></a>`version`

Data type: `Python::Version`

Python version to use.

Default value: `'system'`

##### <a name="-python--pyvenv--systempkgs"></a>`systempkgs`

Data type: `Boolean`

Copy system site-packages into virtualenv

Default value: `false`

##### <a name="-python--pyvenv--venv_dir"></a>`venv_dir`

Data type: `Stdlib::Absolutepath`

Directory to install virtualenv to

Default value: `$name`

##### <a name="-python--pyvenv--owner"></a>`owner`

Data type: `String[1]`

The owner of the virtualenv being manipulated

Default value: `'root'`

##### <a name="-python--pyvenv--group"></a>`group`

Data type: `String[1]`

The group relating to the virtualenv being manipulated

Default value: `'root'`

##### <a name="-python--pyvenv--mode"></a>`mode`

Data type: `Stdlib::Filemode`

Optionally specify directory mode

Default value: `'0755'`

##### <a name="-python--pyvenv--path"></a>`path`

Data type: `Array[Stdlib::Absolutepath]`

Specifies the PATH variable.

Default value: `['/bin', '/usr/bin', '/usr/sbin', '/usr/local/bin',]`

##### <a name="-python--pyvenv--environment"></a>`environment`

Data type: `Array`

Optionally specify environment variables for pyvenv

Default value: `[]`

##### <a name="-python--pyvenv--prompt"></a>`prompt`

Data type: `Optional[String[1]]`

Optionally specify the virtualenv prompt (python >= 3.6)

Default value: `undef`

##### <a name="-python--pyvenv--pip_version"></a>`pip_version`

Data type: `Python::Venv::PipVersion`



Default value: `'latest'`

### <a name="python--requirements"></a>`python::requirements`

Installs and manages Python packages from requirements file.

#### Examples

##### install pip requirements from /var/www/project1/requirements.txt

```puppet
python::requirements { '/var/www/project1/requirements.txt' :
  virtualenv => '/var/www/project1',
  proxy      => 'http://proxy.domain.com:3128',
  owner      => 'appuser',
  group      => 'apps',
}
```

#### Parameters

The following parameters are available in the `python::requirements` defined type:

* [`requirements`](#-python--requirements--requirements)
* [`virtualenv`](#-python--requirements--virtualenv)
* [`pip_provider`](#-python--requirements--pip_provider)
* [`owner`](#-python--requirements--owner)
* [`group`](#-python--requirements--group)
* [`proxy`](#-python--requirements--proxy)
* [`src`](#-python--requirements--src)
* [`environment`](#-python--requirements--environment)
* [`forceupdate`](#-python--requirements--forceupdate)
* [`cwd`](#-python--requirements--cwd)
* [`extra_pip_args`](#-python--requirements--extra_pip_args)
* [`manage_requirements`](#-python--requirements--manage_requirements)
* [`fix_requirements_owner`](#-python--requirements--fix_requirements_owner)
* [`log_dir`](#-python--requirements--log_dir)
* [`timeout`](#-python--requirements--timeout)

##### <a name="-python--requirements--requirements"></a>`requirements`

Data type: `Stdlib::Absolutepath`

Path to the requirements file.

Default value: `$name`

##### <a name="-python--requirements--virtualenv"></a>`virtualenv`

Data type: `Variant[Enum['system'],Stdlib::Absolutepath]`

virtualenv to run pip in.

Default value: `'system'`

##### <a name="-python--requirements--pip_provider"></a>`pip_provider`

Data type: `Enum['pip', 'pip3']`

version of pip you wish to use.

Default value: `'pip'`

##### <a name="-python--requirements--owner"></a>`owner`

Data type: `String[1]`

The owner of the virtualenv being manipulated.

Default value: `'root'`

##### <a name="-python--requirements--group"></a>`group`

Data type: `String[1]`

The group relating to the virtualenv being manipulated.

Default value: `'root'`

##### <a name="-python--requirements--proxy"></a>`proxy`

Data type: `Optional[Stdlib::HTTPUrl]`

Proxy server to use for outbound connections.

Default value: `undef`

##### <a name="-python--requirements--src"></a>`src`

Data type: `Any`

Pip --src parameter to; if the requirements file contains --editable resources, this parameter specifies where they will be installed. See the pip documentation for more.

Default value: `false`

##### <a name="-python--requirements--environment"></a>`environment`

Data type: `Array`

Additional environment variables required to install the packages.

Default value: `[]`

##### <a name="-python--requirements--forceupdate"></a>`forceupdate`

Data type: `Boolean`

Run a pip install requirements even if we don't receive an event from the requirements file - Useful for when the requirements file is written as part of a resource other than file (E.g vcsrepo)

Default value: `false`

##### <a name="-python--requirements--cwd"></a>`cwd`

Data type: `Optional[Stdlib::Absolutepath]`

The directory from which to run the "pip install" command.

Default value: `undef`

##### <a name="-python--requirements--extra_pip_args"></a>`extra_pip_args`

Data type: `Optional[String[1]]`

Extra arguments to pass to pip after the requirements file

Default value: `undef`

##### <a name="-python--requirements--manage_requirements"></a>`manage_requirements`

Data type: `Boolean`

Create the requirements file if it doesn't exist.

Default value: `true`

##### <a name="-python--requirements--fix_requirements_owner"></a>`fix_requirements_owner`

Data type: `Boolean`

Change owner and group of requirements file.

Default value: `true`

##### <a name="-python--requirements--log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`

Log directory.

Default value: `'/tmp'`

##### <a name="-python--requirements--timeout"></a>`timeout`

Data type: `Integer`

The maximum time in seconds the "pip install" command should take.

Default value: `1800`

## Data types

### <a name="Python--Loglevel"></a>`Python::Loglevel`

Match all valid loglevels for python

Alias of `Enum['debug', 'info', 'warning', 'error', 'critical']`

### <a name="Python--Package--Ensure"></a>`Python::Package::Ensure`

Match all valid package ensures for python

Alias of `Enum['absent', 'present', 'latest']`

### <a name="Python--Provider"></a>`Python::Provider`

Match all valid provider for python

Alias of `Enum['pip', 'scl', 'rhscl', 'anaconda', '']`

### <a name="Python--Umask"></a>`Python::Umask`

Match valid umask for python

Alias of `Pattern[/[0-7]{1,4}/]`

### <a name="Python--Venv--PipVersion"></a>`Python::Venv::PipVersion`

A version type to ensure a specific Pip version in a virtual env.

Alias of `Pattern[/^(<|>|<=|>=|==) [0-9]*(\.[0-9]+)*$/, /\Alatest\Z/]`

### <a name="Python--Version"></a>`Python::Version`

Match all valid versions for python

Alias of `Pattern[/\A(python)?[0-9](\.?[0-9])*/, /\Apypy\Z/, /\Asystem\Z/, /\Arh-python[0-9]{2}(?:-python)?\Z/]`

